mylog: Evaluates the natural logarithm of a strictly positive number...

Description Usage Arguments Value Examples

View source: R/mylog.R

Description

Evaluates the natural logarithm of a strictly positive number or vector of strictly positive numbers.

Usage

1
mylog(x)

Arguments

x

A number or vector of numbers.

Value

The logarithm of every element in x

Examples

1
2
mylog(c(1, 2, 3, 4, 5))
mylog(100)

LarryShamalama/RShamalama documentation built on Oct. 30, 2019, 8:23 p.m.